Aggregate and Save Cross-validation Result for Single-omics Analysis
Source:R/SmCCNet-source.R
aggregateCVSingle.RdSaves cross-validation results in a table with the user-defined directory and outputs penalty term with the highest testing canonical correlation, lowest prediction error, and lowest scaled prediction error.
Arguments
- CVDir
A directory where the result is stored.
- SCCAmethod
The canonical correlation analysis method that is used in the model, used to name cross-validation table file, default is set to 'SmCCA'.
- K
number of folds for cross-validation.
- NumSubsamp
Number of subsampling used.
- verbose
Logical; if TRUE, print progress messages during execution, otherwise run silently.